searchData={"items":[{"type":"module","title":"ExOpencc","doc":"Simple wrapper around OpenCC using NIF.","ref":"ExOpencc.html"},{"type":"function","title":"ExOpencc.convert/2","doc":"便捷函数：创建转换器并转换文本","ref":"ExOpencc.html#convert/2"},{"type":"function","title":"参数 - ExOpencc.convert/2","doc":"- `text`: 要转换的文本\n- `config` (可选): 配置文件名，默认为 \"s2t.json\"","ref":"ExOpencc.html#convert/2-参数"},{"type":"function","title":"返回值 - ExOpencc.convert/2","doc":"- `{:ok, converted_text}` - 转换成功\n- `{:error, reason}` - 转换失败","ref":"ExOpencc.html#convert/2-返回值"},{"type":"function","title":"示例 - ExOpencc.convert/2","doc":"iex> {:ok, result} = ExOpencc.convert(\"简体中文\")\n    iex> result\n    \"簡體中文\"\n    \n    iex> {:ok, result} = ExOpencc.convert(\"簡體中文\", \"t2s.json\")\n    iex> result\n    \"简体中文\"","ref":"ExOpencc.html#convert/2-示例"},{"type":"function","title":"ExOpencc.convert_sync/2","doc":"同步转换文本","ref":"ExOpencc.html#convert_sync/2"},{"type":"function","title":"参数 - ExOpencc.convert_sync/2","doc":"- `converter`: 转换器实例\n- `text`: 要转换的文本","ref":"ExOpencc.html#convert_sync/2-参数"},{"type":"function","title":"返回值 - ExOpencc.convert_sync/2","doc":"- `{:ok, converted_text}` - 转换成功\n- `{:error, reason}` - 转换失败","ref":"ExOpencc.html#convert_sync/2-返回值"},{"type":"function","title":"示例 - ExOpencc.convert_sync/2","doc":"iex> {:ok, converter} = ExOpencc.new(\"s2t.json\")\n    iex> {:ok, result} = ExOpencc.convert_sync(converter, \"简体中文\")\n    iex> result\n    \"簡體中文\"","ref":"ExOpencc.html#convert_sync/2-示例"},{"type":"function","title":"ExOpencc.load_nif/0","doc":"","ref":"ExOpencc.html#load_nif/0"},{"type":"function","title":"ExOpencc.new/0","doc":"创建一个新的 OpenCC 转换器实例","ref":"ExOpencc.html#new/0"},{"type":"function","title":"参数 - ExOpencc.new/0","doc":"- `config` (可选): 配置文件名，默认为 \"s2t.json\"","ref":"ExOpencc.html#new/0-参数"},{"type":"function","title":"返回值 - ExOpencc.new/0","doc":"- `{:ok, converter}` - 成功创建转换器\n- `{:error, reason}` - 创建失败","ref":"ExOpencc.html#new/0-返回值"},{"type":"function","title":"示例 - ExOpencc.new/0","doc":"iex> {:ok, converter} = ExOpencc.new()\n    iex> {:ok, converter} = ExOpencc.new(\"s2t.json\")\n    iex> {:ok, converter} = ExOpencc.new(\"t2s.json\")","ref":"ExOpencc.html#new/0-示例"},{"type":"function","title":"ExOpencc.new/1","doc":"","ref":"ExOpencc.html#new/1"},{"type":"extras","title":"ExOpencc","doc":"# ExOpencc\n\nExOpencc 是基于 OpenCC 的 Elixir NIF 封装，提供简繁中文互转功能。","ref":"readme.html"},{"type":"extras","title":"安装 - ExOpencc","doc":"在 `mix.exs` 中添加依赖：\n\n```elixir\ndef deps do\n  [\n    {:ex_opencc, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#安装"},{"type":"extras","title":"编译 - ExOpencc","doc":"首先获取 OpenCC 源代码：\n\n```bash\ngit submodule update --init --recursive\n```\n\n然后编译：\n\n```bash\nmake ex_opencc\n# 或者\nmix compile\n```","ref":"readme.html#编译"},{"type":"extras","title":"基本用法 - ExOpencc","doc":"","ref":"readme.html#基本用法"},{"type":"extras","title":"创建转换器 - ExOpencc","doc":"```elixir\n# 默认使用 \"s2t.json\"\n{:ok, converter} = ExOpencc.new()\n\n# 指定配置文件\n{:ok, converter} = ExOpencc.new(\"s2t.json\")\n```","ref":"readme.html#创建转换器"},{"type":"extras","title":"同步转换文本 - ExOpencc","doc":"```elixir\n{:ok, converter} = ExOpencc.new(\"s2t.json\")\n{:ok, result} = ExOpencc.convert_sync(converter, \"简体中文\")\nIO.puts(result) # => \"簡體中文\"\n\n# 处理空字符串\n{:ok, result} = ExOpencc.convert_sync(converter, \"\")\nIO.puts(result) # => \"\"\n```","ref":"readme.html#同步转换文本"},{"type":"extras","title":"简繁互转 - ExOpencc","doc":"```elixir\n# 简体转繁体\n{:ok, converter} = ExOpencc.new(\"s2t.json\")\n{:ok, result} = ExOpencc.convert_sync(converter, \"简体中文\")\nIO.puts(result) # => \"簡體中文\"\n\n# 繁体转简体\n{:ok, converter} = ExOpencc.new(\"t2s.json\")\n{:ok, result} = ExOpencc.convert_sync(converter, \"簡體中文\")\nIO.puts(result) # => \"简体中文\"\n```","ref":"readme.html#简繁互转"},{"type":"extras","title":"错误处理 - ExOpencc","doc":"```elixir\nresult = ExOpencc.convert_sync(:invalid_resource, \"测试\")\n# result => {:error, reason}\n```","ref":"readme.html#错误处理"},{"type":"extras","title":"批量转换示例 - ExOpencc","doc":"```elixir\ntest_cases = [\n  {\"简体中文\", \"簡體中文\"},\n  {\"中华人民共和国\", \"中華人民共和國\"},\n  {\"北京大学\", \"北京大學\"},\n  {\"软件工程\", \"軟件工程\"}\n]\n\n{:ok, converter} = ExOpencc.new(\"s2t.json\")\n\nfor {input, expected} <- test_cases do\n  {:ok, result} = ExOpencc.convert_sync(converter, input)\n  IO.puts(\"#{input} -> #{result}\")\nend\n```","ref":"readme.html#批量转换示例"},{"type":"extras","title":"支持的配置 - ExOpencc","doc":"| 配置文件 | 转换方向 | 说明 |\n|---------|---------|------|\n| `s2t.json` | 简体 → 繁体 | 简体中文转换为繁体中文 |\n| `t2s.json` | 繁体 → 简体 | 繁体中文转换为简体中文 |\n| `s2tw.json` | 简体 → 台湾繁体 | 简体中文转换为台湾地区的繁体中文 |\n| `tw2s.json` | 台湾繁体 → 简体 | 台湾地区的繁体中文转换为简体中文 |\n| `s2hk.json` | 简体 → 香港繁体 | 简体中文转换为香港地区的繁体中文 |\n| `hk2s.json` | 香港繁体 → 简体 | 香港地区的繁体中文转换为简体中文 |\n| `s2twp.json` | 简体 → 台湾繁体（短语） | 简体中文转换为台湾地区的繁体中文，包含短语转换 |\n| `tw2sp.json` | 台湾繁体（短语） → 简体 | 台湾地区的繁体中文转换为简体中文，包含短语转换 |","ref":"readme.html#支持的配置"},{"type":"extras","title":"API 文档 - ExOpencc","doc":"","ref":"readme.html#api-文档"},{"type":"extras","title":"ExOpencc.new/0, ExOpencc.new/1 - ExOpencc","doc":"创建新的 OpenCC 转换器。\n\n**参数**\n- `config` (可选) 配置文件名，默认 `\"s2t.json\"`\n\n**返回值**\n- `{:ok, converter}` 创建成功\n- `{:error, reason}` 创建失败","ref":"readme.html#exopencc-new-0-exopencc-new-1"},{"type":"extras","title":"ExOpencc.convert_sync/2 - ExOpencc","doc":"使用给定的转换器同步转换文本。\n\n**参数**\n- `converter` 转换器实例\n- `text` 要转换的文本\n\n**返回值**\n- `{:ok, converted}` 转换成功\n- `{:error, reason}` 转换失败","ref":"readme.html#exopencc-convert_sync-2"},{"type":"extras","title":"许可证 - ExOpencc","doc":"项目基于 OpenCC","ref":"readme.html#许可证"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}